@@ -14,12 +14,6 @@ describe 'designate::backend::powerdns' do
       it 'configures designate backend powerdns with default parameters' do
         is_expected.to contain_designate_config('backend:powerdns/connection').with_value('mysql://dbserver')
         is_expected.to contain_designate_config('backend:powerdns/use_db_reconnect').with_value(true)
-        is_expected.to contain_file('/var/lib/designate').with(
-          'ensure' => 'directory',
-          'owner'  => 'designate',
-          'group'  => 'designate',
-          'mode'   => '0750',
-        )
       end
 
       it 'includes designate::db::powerdns::sync' do
